==> macrofocus-common-js-2020.2.0-sources.jar: jsMain/com/macrofocus/common/format/FormatFactory.kt <==
package com.macrofocus.common.format

import com.macrofocus.common.date.CPTimeZone
import com.macrofocus.common.locale.CPLocale

/**
 * Created by luc on 14/12/15.
 */
actual class FormatFactory {
    actual fun createOrdinalFormat(): CPFormat<Any?> {
        TODO("Not yet implemented")
    }

    actual fun createMilionFormat(decimalFormat: CPFormat<Any?>): CPFormat<Any?> {
        TODO("Not yet implemented")
    }

    actual fun createDecimalFormat(): CPFormat<Any?> {
        return object: CPFormat<Any?> {
            override fun format(value: Any?): String? {
                return value.toString()
            }

            override fun formatHtml(value: Any?, htmlSupported: Boolean): String? {
                if(!htmlSupported) {
                    return format(value)
                } else {
                    return value.toString()
                }
            }

            override fun parse(text: String?): Any? {
                TODO("Not yet implemented")
            }

            override val pattern: String?
                get() = TODO("Not yet implemented")
            override val nativeFormat: Any?
                get() = TODO("Not yet implemented")
            override val horizontalAlignment: CPFormat.HorizontalAlignment?
                get() = TODO("Not yet implemented")

            override fun getClassName(value: Any?): String? {
                TODO("Not yet implemented")
            }
        }
    }

    actual fun createDecimalFormat(fractionDigits: Int): CPFormat<Any?> {
        TODO("Not yet implemented")
    }

    actual fun createDecimalFormat(
        fractionDigits: Int,
        pre: String?,
        post: String?,
        rounding: Double,
        factor: Double
    ): CPFormat<Any?> {
        TODO("Not yet implemented")
    }

    actual fun createIntegerFormat(): CPFormat<Any?> {
        TODO("Not yet implemented")
    }

    actual fun createIntegerFormat(
        pre: String?,
        post: String?,
        rounding: Double
    ): CPFormat<Any?> {
        TODO("Not yet implemented")
    }

    actual fun createPercentDecimalFormat(fractionDigits: Int): CPFormat<Any?> {
        TODO("Not yet implemented")
    }

    actual fun createPercentDecimalFormat(
        fractionDigits: Int,
        rounding: Double
    ): CPFormat<Any?> {
        TODO("Not yet implemented")
    }

    actual fun createStarFormat(): CPFormat<Any?> {
        TODO("Not yet implemented")
    }

    actual fun createStarFormat(na: String?): CPFormat<Any?> {
        TODO("Not yet implemented")
    }

    actual fun createBooleanFormat(): CPFormat<Any?> {
        TODO("Not yet implemented")
    }

    actual fun createDateFormat(): CPFormat<Any?> {
        TODO("Not yet implemented")
    }

    actual fun createDateTimeFormat(): CPFormat<Any?> {
        TODO("Not yet implemented")
    }

    actual fun createDateOrDateTimeFormat(): CPFormat<Any?> {
        TODO("Not yet implemented")
    }

    actual fun createNumberFormat(pattern: String?): CPFormat<Any?> {
        TODO("Not yet implemented")
    }

    actual fun createDateFormat(pattern: String?): CPFormat<Any?> {
        TODO("Not yet implemented")
    }

    actual fun createDateFormat(
        pattern: String?,
        locale: CPLocale?
    ): CPFormat<Any?> {
        TODO("Not yet implemented")
    }

    actual fun createDateFormat(
        pattern: String?,
        locale: CPLocale?,
        zone: CPTimeZone?
    ): CPFormat<Any?> {
        TODO("Not yet implemented")
    }

    actual fun createFormat(
        pre: String?,
        post: String?
    ): CPFormat<Any?> {
        TODO("Not yet implemented")
    }

    actual companion object {
        actual val instance: FormatFactory = FormatFactory()
    }

}

==> macrofocus-common-js-2025.0.4-sources.jar: jsMain/com/macrofocus/common/format/FormatFactory.kt <==
package com.macrofocus.common.format

import com.macrofocus.common.date.CPTimeZone
import com.macrofocus.common.locale.CPLocale

/**
 * Created by luc on 14/12/15.
 */
actual open class FormatFactory : FormatFactoryCommon {
     actual fun createDecimalFormat(): CPFormat<Any?> {
        return object: CPFormat<Any?> {
            override fun format(value: Any?): String? {
                return value.toString()
            }

            override fun formatHtml(value: Any?, htmlSupported: Boolean): String? {
                if(!htmlSupported) {
                    return format(value)
                } else {
                    return value.toString()
                }
            }

            override fun parse(text: String?): Any? {
                TODO("Not yet implemented")
            }

            override val pattern: String?
                get() = TODO("Not yet implemented")
            override val nativeFormat: Any?
                get() = TODO("Not yet implemented")
            override val horizontalAlignment: CPFormat.HorizontalAlignment?
                get() = TODO("Not yet implemented")

            override fun getClassName(value: Any?): String? {
                TODO("Not yet implemented")
            }
        }
    }


    actual companion object {
        actual val instance: FormatFactory = FormatFactory()
    }

    actual override fun createIntegerFormat(pre: String?, post: String?, rounding: Double): CPFormat<Any?> {
        TODO("Not yet implemented")
    }

    actual override fun createPercentDecimalFormat(fractionDigits: Int, rounding: Double): CPFormat<Any?> {
        TODO("Not yet implemented")
    }

    actual fun createDateFormat(): CPFormat<Any?> {
        TODO("Not yet implemented")
    }

    actual fun createDateFormat(pattern: String?): CPFormat<Any?> {
        TODO("Not yet implemented")
    }

    actual fun createDateFormat(pattern: String, locale: CPLocale?): CPFormat<Any?> {
        TODO("Not yet implemented")
    }

    actual fun createDateFormat(
        pattern: String,
        locale: CPLocale?,
        zone: CPTimeZone?
    ): CPFormat<Any?> {
        TODO("Not yet implemented")
    }

    actual fun createDateTimeFormat(): CPFormat<Any?> {
        TODO("Not yet implemented")
    }

    actual fun createDateOrDateTimeFormat(): CPFormat<Any?> {
        TODO("Not yet implemented")
    }

    actual fun createNumberFormat(pattern: String?): CPFormat<Any?> {
        return createDecimalFormat(0)!!
    }
}
